
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef EKG_H
#define EKG_H

#include <cstdlib>
#include <fstream>
#include <unistd.h>
#include "calibrate.h"
#include "EKGdevice.h"
#include "EKGbuffer.h"
#include "EKGfreq.h"
#include "EKGhfilter.h"
#include "EKGlfilter.h"
#include "EKGplotter.h"
#include "EKGsource.h"
#include "EKGlogger.h"
using namespace std;

/**
 * Aufnahme von EKG an der Komandozeile. Aufruf:
 * <p>
 * <tt><strong>ekg -r [-w time] device</strong></tt>
 * Rohdaten der Kanle ausgeben. Zum kalibrieren der Meverstrker. Beenden
 * mit ^C.
 * <p>
 * <tt><strong>ekg -p file [-g file] [-T ts] [-V vs] [options] device</strong>
 * </tt>
 * EKG als Postscript ausgeben. Die Aufnahmelnge wird durch die Zeitskala
 * ts bestimmt. Die Zeitskala ts wird in mm/s und die Spannungsskala vs in
 * mm/mV angegeben. Voreingestellt sind ts = 50 mm/s und vs = 20 mm/mV. Die
 * Mewerte knnen mit -g zustzlich in eine Datei geschrieben werden.
 * <p>
 * <tt><strong>ekg -g file [-t time] [options] device</strong></tt>
 * EKG in Rohdaten ausgeben. Die Aufnahme endet bei einem Tastendruck oder
 * nach time Sekunden.
 * <p>
 * <strong>Optionen:</strong>
 * <dl>
 *   <dt> -w time <dd> Wartezeit vor der Aufnahme
 *   <dt> -L[freq] <dd> Tifpass einschalten [mit Grenzfrequenz freq].
 *   Standardgrenzfrequenz ist 10Hz.
 *   <dt> -H[time] <dd> Hochpass einschalten [mit Zeitkonstante time].
 *   Standardzeitkonstante ist 0,3 s.
 *   <dt> -P <dd> Pulsausgabe auf stderr.
 *   <dt> -S <dd> Tonausgabe auf stderr.
 *   <dt> -N name <dd> Name (und Geb. Datum) des Patienten
 * </dl>
 *
 * @author Lars Stollenwerk, Februar 2003
 */
class EKG
{
public:
  /// Konstruktor. bernimmt die Kommandozeilenoptionen.
  EKG( int argc, char *argv[] );
  /// Messung durchfhren 
  void run();
private:
  //
  // Kommandozeilenwerte
  // 

  /// Mewerte (GnuPlot) in Datei schreiben.
  char * g;
  /// Hilfe ausgeben.
  bool h;
  /// Postscript Dateiname
  char * p;
  /// Rohdaten ausgeben
  bool r;
  /// Aufnahmezeit in s. 0 = unendlich
  int t;
  /// Wartezeit vor der Messung
  int w;
  /// Zeitkonstante Hochpass. -1 = aus.
  float H;
  /// Frequenz des Tiefpass. -1 = aus.
  float L;
  /// Name (und Geb. Datum) des Patienten
  char * N;
  /// Pulsausgabe auf stderr.
  bool P;
  /// Tonausgabe auf stderr.
  bool S;
  /// Zeitskala. Standard ist 50 mm/s.
  float T;
  /// Spannugnsskala, Standard ist 20 mm/mV.
  float V;
  /// Serielle Schnittstelle
  char * device;
  
  //
  // EKGdevices
  //

  /// Quelle liest von serieller Schnittstelle.
  EKGsource Source;
  /// Tiefpafilter
  EKGhfilter Hfilter;
  /// Hochpafilter
  EKGlfilter Lfilter;
  /// Pulsfrequenzmesser. Ausgabe in Zahl und Ton auf stderr.
  EKGfreq Freq;
  /// Ende der Mekette
  EKGdevice & Pipeend;
  
  //
  // Methoden
  //
  
  /// Vor der Messung warten.
  void wait();
  /// Hilfe auf stdout drucken.
  void help();
  /// Programm Postscript (-p).
  void program_ps();
  /// Programm Datenfile (-g).
  void program_data();

};

#endif
