
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef EKGHFILTER_H
#define EKGHFILTER_H

#include <string>
#include <cmath>
#include "calibrate.h"
#include "EKGfilter.h"
using namespace std;

/**
 * Diese Klasse implementiert einen Hochpafilter. Der Hochpafilter dient
 * der Unterdrckung des Gleichanteils im Signal, der durch
 * Muskelbewegungen des Patienten schwanken kann.
 * <p>
 * <b>Hochpafilter</b>
 * <p>
 * Es wird ein RC-Glied simuliert, dessen Ausgangswert a vom
 * Eingangssignal e abgezogen wird.
 <pre>
   o-----/\/\/\/----+----o
  |      R          |     |
 e|               -----   | a
  |             C -----   |
  V                 |     V
   o----------------+----o
 </pre>
 * Der Filter wird durch die DGL
 <pre>
    a' = 1/t ( e - a )
 </pre>
 * beschrieben.  Die Zeitkonstante t = RC kann mit setHTimeConstant()
 * eingestellt werden.  voreinstellung ist t = 0,3 s. 
 *
 * @author Lars Stollenwerk, Oktober 2002
 */
class EKGhfilter : public EKGfilter
{
  public:
    /**
     * Konstruktor
     */
    EKGhfilter()
    { 
      setHTimeConstant( 0.3 ); 
      Ha[0] = Ha[1] = Ha[2] = 0; 
    }
    /**
     * Zeitkonstante fr Hochpafilter setzen. 
     * @param x t in Sekunden.
     * @return alter Wert.
     */
    float setHTimeConstant( float x );
    /// Zeitkonstante erfragen
    float getHTimeConstant() { return EKG_TimeStep / Ht; }
    /**
     * berschreiben von EKGdevice::input(). Hier werden die DGL fr die
     * Filter numerisch gelst.
     * <p>
     * <b>Hochpafilter</b>
     * <p>
     * Die DGL eines RC-Gliedes <tt> Ua' = 1/t ( Ue - Ua ) </tt> wird in eine
     * Differenzengleichung berfhrt.
     <pre>
     Delta a = TS / t ( e - a )
     </pre>
     */
    virtual void input( float * d );
  private:
    // ----------------------------------------------------------------------
    // Hochpa
    // ----------------------------------------------------------------------

    /// Zeitkonstante des Hochpafilters. <tt> Ht = EKG_TimeStep / t </tt>
    float Ht;
    /// ,,Kondensator'' fr den Hochpafilter.
    float Ha[3];
};

#endif
